# API Reference

## Public API

### `litestar_sendparcel`

```{eval-rst}
.. automodule:: litestar_sendparcel
   :members:
   :undoc-members:
```

### Configuration

```{eval-rst}
.. automodule:: litestar_sendparcel.config
   :members:
   :undoc-members:
   :show-inheritance:
```

### Plugin factory

```{eval-rst}
.. automodule:: litestar_sendparcel.plugin
   :members:
   :undoc-members:
```

### Registry

```{eval-rst}
.. automodule:: litestar_sendparcel.registry
   :members:
   :undoc-members:
   :show-inheritance:
```

### Protocols

```{eval-rst}
.. automodule:: litestar_sendparcel.protocols
   :members:
   :undoc-members:
   :show-inheritance:
```

### Schemas

```{eval-rst}
.. automodule:: litestar_sendparcel.schemas
   :members:
   :undoc-members:
   :show-inheritance:
```

## Route handlers

### Shipment endpoints

```{eval-rst}
.. automodule:: litestar_sendparcel.routes.shipments
   :members:
   :undoc-members:
```

### Callback endpoints

```{eval-rst}
.. automodule:: litestar_sendparcel.routes.callbacks
   :members:
   :undoc-members:
```

### Retry helpers

```{eval-rst}
.. automodule:: litestar_sendparcel.retry
   :members:
   :undoc-members:
```
